@@ -13,12 +13,9 @@ import statistics
 from uuid import uuid4, UUID
 import math
 import statistics
-from collections import OrderedDict
 from dataclasses import dataclass, field
 import logging
 
-from trp import Geometry
-
 logger = logging.getLogger(__name__)
 
 
